@@ -6,13 +6,13 @@ use Carp;
 
 #==================================================================
 # $Author    : Djibril Ousmanou                                   $
-# $Copyright : 2011                                               $
-# $Update    : 19/07/2011 22:48:20                                $
+# $Copyright : 2017                                               $
+# $Update    : 23/01/2017                                         $
 # $AIM       : Create pie graph                                   $
 #==================================================================
 
 use vars qw($VERSION);
-$VERSION = '1.04';
+$VERSION = '1.05';
 
 use base qw/ Tk::Derived Tk::Canvas::GradientColor /;
 use Tk::Balloon;
@@ -472,9 +472,15 @@ sub _viewlegend {
     }
   }
 
-  #Balloon
-  if ( not defined $cw->{RefChart}->{Balloon}{Obj} ) {
-    $cw->{RefChart}->{Balloon}{Obj} = $cw->Balloon(
+  # Balloon
+  # Destroy the existing ballon to use new data.
+  if ( defined $cw->{RefChart}->{Balloon}{Obj} ) {
+    $cw->{RefChart}->{Balloon}{Obj}->destroy;
+    $cw->{RefChart}->{Balloon}{Obj} = undef;
+  }
+  
+  # Create the balloon
+  $cw->{RefChart}->{Balloon}{Obj} = $cw->Balloon(
       -statusbar  => $cw,
       -background => $cw->{RefChart}->{Balloon}{Background},
     );
@@ -484,7 +490,6 @@ sub _viewlegend {
       -balloonposition => 'mouse',
       -msg             => \%msgballoon,
     );
-  }
 
   return;
 }
